@@ -91,7 +91,7 @@ class SimpleWaypointEnv(gymnasium.Env):
             }
         )
 
-        a_lim = 0.3 * math.pi
+        a_lim = math.pi / 3.0
         t_lim = 0.6
         high = np.array([a_lim, a_lim, a_lim, t_lim])
         low = np.array([-a_lim, -a_lim, -a_lim, 0.0])
